PoseFix dataset, Copyright (c) 2023 Institut de Robòtica i Informàtica Industrial, CSIC-UPC / Naver Corporation

# PoseFix dataset

## License

The PoseFix dataset is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 license.

A summary of the CC BY-NC-SA 4.0 license is located here:
	https://creativecommons.org/licenses/by-nc-sa/4.0/

The CC BY-NC-SA 4.0 license is located here:
	https://creativecommons.org/licenses/by-nc-sa/4.0/legalcode
    

## Citation

If you use our dataset, please cite our ICCV'23 paper:

```
@inproceedings{delmas2023posefix,
  title={{PoseFix: Correcting 3D Human Poses with Natural Language}},
  author={{Delmas, Ginger and Weinzaepfel, Philippe and Moreno-Noguer, Francesc and Rogez, Gr\'egory}},
  booktitle={{ICCV}},
  year={2023}
}
```

## Overview

The PoseFix dataset is composed of *{pose A, pose B, text modifier}* triplets, where *pose B* (the target pose) is the result of the correction of *pose A* (the source pose), as specified by the text modifier. Text modifiers were either generated automatically or written by human annotators.

**We consider 100k poses and 135305 pose pairs, 6157 of which are annotated by humans** (26 of them are annotated twice). **Each pair is additionally accompanied by 3 modifiers generated automatically by our pipeline.** Each generated modifier is different. While the generative process itself is random, we also changed the pipeline slightly over the 3 runs, specifically:
- no paircode was skipped when producing the 1st modifier (conversely to the other two),
- the 3rd modifier was generated without going through the aggregation step of the pipeline (conversely to the other two).

Please refer to the paper for more details about the overall automatic generation process or the collection process of the human-written annotations.

We additionally provide **4284 lists of paraphrases** generated thanks to InstructGPT for each pair of the training set that was annotated with human-written modifiers (see section below for more details). Each pair has an average of 2.03 paraphrases.


## File organization

Text modifier are provided through files `posefix_auto_135305.json`, `posefix_human_6157.json` and `posefix_paraphrases_4284.json`, which are organized as follow:
```
{
    "<data_ID>" : [<modifier 1>, <modifier 2> ...],
    ...
}
```

The file `pair_id_2_pose_ids.json` links the pair ID (the list index) to the IDs of the poses forming the pair. The file is organized as follow:
```
[
    [<pose_A_ID>, <pose_B_ID>],
    ...
]
```

The file `ids_2_dataset_sequence_and_frame_index_100k.json` links pose IDs to information about the pose origin, in order to retrieve the pose data (eg. joint rotations). Pose data can be found in the AMASS dataset (https://amass.is.tue.mpg.de/), which use is subject to the following terms and conditions: https://amass.is.tue.mpg.de/license.html. For additional information on the dataset see “AMASS: Archive of Motion Capture as Surface Shapes” by Mahmood et al. (ICCV 2019). The file is organized as follow:

```
{
    "<pose_ID>": [
        "<dataset>",
        "<relative path to the sequence>",
        <frame index in the sequence>
    ],
    ...
}
```

The files `(train|val|test)_(in|out)_sequence_pair_ids.json` (6 files) provide the list of pair IDs considered in each split. We split the dataset into roughly 70% for training, 10% for validation and 20% for testing while ensuring that poses from the same pose sequence belong to the same split. The number of annotated pairs per split is as follow:

| sub-dataset    | train  | val    | test   | total   |
|----------------|--------|--------|--------|---------|
| automatic      | 93,701 | 13,839 | 27,765 | 135,305 |
| human          |  4,284 |    634 |  1,239 |   6,157 |

Split information files are organized as follow:

```
[
    ...
    "<pair_ID>",
    ...
]
```

Pairs are either "in-sequence" or "out-of-sequence" depending on whether both poses in the pair come from the same motion sequence in AMASS or not. Related numbers are provided in the table below: 

| subset          | train  | val    | test   | total   |
|-----------------|--------|--------|--------|---------|
| in-sequence     | 16,606 |  2,834 |  5,761 |  25,201 |
| out-of-sequence | 77,095 | 11,005 | 22,004 | 110,104 |

Besides, some pairs are annotated in both ways (ie. we have a modifier for *pose A* to *pose B* and for the way back as well: *pose B* to *pose A*). Related numbers are provided in the table below: 


| subset          | train  | val    | test   | total   |
|-----------------|--------|--------|--------|---------|
| both-way pairs  | 65,598 |  9,024 | 18,558 |  93,180 |
| one-way pairs   | 28,103 |  4,815 |  9,207 |  42,125 |


## Notice regarding the file `posefix_paraphrases_4284.json`

The texts in the file `posefix_paraphrases_4284.json` were generated in part using InstructGPT, OpenAI’s large-scale language-generation model. Specifically, the OpenAI API was used to generate two paraphrases of instructions listed in `posefix_human_6157.json`. After using InstructGPT to generate the texts in the file `posefix_paraphrases_4284.json`, the texts were reviewed, edited, and revised to satisfy the needs of the project. The contents of the file `posefix_paraphrases_4284.json` is therefore not the responsibility of OpenAI.